.\" cmns.man
.\" common text describing commands common to sratool and radtool
.\" expects \*(SR to contain RAD or SRA
.\" and \(TL to contain sratool or radtool
.It Ic accounting
Tell the server to report counts of packets seen, missed, sent, and lost.
.It Ic alias
List the available connection aliases (culled from the axa client config file).
.It Ic ciphers Op cipher-list
set the list of ciphers for the next TLS connection or show the current
contents of the list.
.It Xo
.Ic connect
.Oo
.Sm off Ar alias Sm on
|
.Sm off Ar apikey: Ar <apikey>@ Ar host,port Sm on
|
.Sm off Ar tcp: Oo Ar user@ Oc Ar host,port Sm on
|
.Sm off Ar unix: Oo Ar user@ Oc Ar /ud/socket Sm on
|
.Sm off Ar ssh: Oo Ar user@ Oc Ar host Sm on
|
.Sm off Ar tls:cert,key@host,port Sm on
.Oc
.Xc
By itself
.Ic connect
shows the current connection.
Otherwise connect to the specified \*(SR server.
.Pp
.Ic alias:
use a connection alias specified in the AXA config file (see FILES).
.Pp
.Ic apikey:
identify and authenticate the user via a Farsight Security provided apikey.
The connection will be encrypted using the same TLS semantics as the tls
transport below.
.Pp
.Ic ssh:
connections use
.Xr ssh 1
configuration files including
.Xr ssh_config 5
to specify the required public keys
and optionally the fully qualified host names and user names associated
with the public key.
Use the "debug 4" command to diagnose ssh connection problems. Note that SSH
transport is deprecated and users are encouraged to use TLS.
.Pp
.Ic tls:
connections use the SSL certificate in the
.Ar cert
file and the private key in the
.Ar key
file.
If not absolute, the files are in the
.Fl S Ar certs
directory.
.Pp
.Ic tcp:
unused.
.Pp
.Ic unix:
unused.
.Pp
.It Ic count Op N | off
sets terminal output to stop displaying packets after a
number of packets (including immediately with a number of 0),
show the currently remaining count,
or turn off the packet count limit.
.It Ic debug Op on | off | quiet | N
increases, decreases or shows the level of debugging and tracing messages
that is also controlled by
.Fl d .
.Ic Debug\ quiet
turns off reports of successful AXA commands.
.It Ic disconnect
disconnects from the \*(SR server.
.It Ic error mode Op disconnect | off
disconnects from the \*(SR server and exits
when the server reports an error or the connection breaks.
In the default mode
.Em "error mode off" ,
errors are only reported.
.It Ic exit
Ends the program.
.It Ic go
Tell the \*(SR server to resume sending data.
.Nm .
.It Ic help Op command
lists all commands or describes a single command.
.It Ic mode Op SRA | RAD
Show the current command mode or
expect to connect to an SRA or RAD server.
The default command mode is set by the name of the program.
.It Ic nop
sends a command to the server that does nothing but test the connection.
.It Ic forward
Start, stop or show the state of forwarding packets received from the server.
Received NMSG messages and IP packets can be forwarded as NMSG messages to
a TCP or UDP port.
Received IP packets can be forwarded as a pcap stream to a file,
to a FIFO created with separately with
.Xr mkfifo 1 ,
or in Ethernet frames on a named network interface to a 48-bit address.
.ds CT Op Ar count
.so fwd.man
.Pp
If
.Ar count
is present, forwarding stops after that many packets.
.It Ic pause
Tell the \*(SR server to stop sending data.
.It Ic rate limit Oo
.Op Ar -|MAX|per-sec
.Op Ar -|NEVER|report-secs
.Oc
Tell the \*(SR server to report its rate limits
or set rate limits and the interval between rate limit reports.
Hits in excess of the rate limit are discarded by the server.
.It Ic radd
Change to RAD mode.
.It Ic sample Op Ar X%
Get and optionally set the percentage of hits that the \*(SR servers sends.
.It Ic sleep x.y
Do nothing for x.y seconds.
.It Ic source filename
reads and executes commands from a file.
.It Ic srad
Change to SRA mode.
.It Ic status
Show information about the current connection state including time connected.
.It Ic trace Ar N
Set the server trace level to N.
.It Ic user Ar name
sends a username to the server (not used for SSH/TLS-based connections).
.It Ic verbose Op on | off | N
controls the length of SIE message and IP packet descriptions.
The default,
.Em "verbose off" ,
generally displays one line summaries.
.It Ic version
displays the version of
.Nm
and its version of the AXA protocol.
.It Ic window Op Ar bufsize
Get and optionally set the TCP output buffer size or maximum send window
used by the server.
.It Ic zlib
Toggle NMSG zlib container compression.
.\"
.\" end of cmds.man
